@@ -20,6 +20,7 @@ from .io import write_dict
 from .terminal import Symbols as termSymbol
 
 from .database.generated import BaseRun, PFDBObj, PFDBObjListNumber
+from .export import SubsurfacePropertiesExporter
 
 def check_parflow_execution(out_file):
     """Helper function that can be used to parse ParFlow output file
@@ -109,6 +110,12 @@ def get_process_args():
                         dest="skipValidation",
                         action='store_true',
                         help="Disable validation pass")
+
+    group.add_argument("--dry-run",
+                        default=False,
+                        action='store_true',
+                        dest="dry_run",
+                        help="Prevent execution")
     # ++++++++++++++++
     group = parser.add_argument_group('Error handling settings')
     group.add_argument("--show-line-error",
@@ -129,6 +136,12 @@ def get_process_args():
                         dest="writeYAML",
                         action='store_true',
                         help="Enable config to be written as YAML file")
+
+    group.add_argument("--validation-error",
+                        default=False,
+                        dest="validation_error",
+                        action='store_true',
+                        help="Only print validation results for key/value pairs with errors")
     # ++++++++++++++++
     group = parser.add_argument_group('Parallel execution')
     group.add_argument("-p", type=int, default=0,
@@ -141,7 +154,8 @@ def get_process_args():
                         dest="r",
                         help="R allocates the number of processes to the grid-cells in z")
 
-    return parser.parse_args()
+    args, unknown = parser.parse_known_args()
+    return args
 
 # -----------------------------------------------------------------------------
 
@@ -174,9 +188,6 @@ def update_run_from_args(run, args):
     if args.r and run.Process.Topology.R != args.r:
         run.Process.Topology.R = args.r
 
-    if args.writeYAML:
-        run.write(file_format='yaml')
-
 # -----------------------------------------------------------------------------
 
 class Run(BaseRun):
@@ -223,6 +234,16 @@ class Run(BaseRun):
         write_dict(self.get_key_dict(), full_file_path)
         return full_file_path, full_file_path[:-(len(file_format)+1)]
 
+    def write_subsurface_table(self, file_name=None):
+        if file_name is None:
+            file_name = f'{self._name_}_subsurface.csv'
+        full_path = get_absolute_path(file_name)
+        exporter = SubsurfacePropertiesExporter(self)
+        if file_name.lower().endswith('.csv'):
+            exporter.write_csv(full_path)
+        else:
+            exporter.write_txt(full_path)
+
     def clone(self, name):
         """Method to generate a clone of a run (for generating
         run ensembles, etc.)
@@ -276,11 +297,17 @@ class Run(BaseRun):
         print(f'# ParFlow database')
         print(f'#  - {os.path.basename(file_name)}')
         print(f'# {"="*78}')
-        print()
 
+        # Only write YAML in run()
+        if self._process_args_.writeYAML:
+            full_path, no_extension = self.write(file_format='yaml')
+            print(f'YAML output: "{full_path}"')
+
+        print()
         error_count = 0
         if not (skip_validation or self._process_args_.skipValidation):
-            error_count += self.validate()
+            skip_valid = True if self._process_args_.validation_error else False
+            error_count += self.validate(skip_valid=skip_valid)
             print()
 
         p = self.Process.Topology.P
@@ -292,10 +319,12 @@ class Run(BaseRun):
         #     ['/bin/sh', '$PARFLOW_DIR/bin/run', run_file, str(num_procs)],
         #     cwd=PFDBObj.working_directory
         # )
-        os.chdir(settings.WORKING_DIRECTORY)
-        os.system(f'sh $PARFLOW_DIR/bin/run {run_file} {num_procs}')
+        success = True
+        if not self._process_args_.dry_run:
+            os.chdir(settings.WORKING_DIRECTORY)
+            os.system(f'sh $PARFLOW_DIR/bin/run {run_file} {num_procs}')
+            success = check_parflow_execution(f'{run_file}.out.txt')
 
-        success = check_parflow_execution(f'{run_file}.out.txt')
         print()
         if not success or error_count > 0:
             sys.exit(1)
@@ -325,3 +354,4 @@ class Run(BaseRun):
         from parflowio.pyParflowio import PFData
         pfb_data = PFData(pfb_file_full_path)
         pfb_data.distFile(p, q, r, pfb_file_full_path)
+
