@@ -176,12 +176,12 @@ def extract_keys_from_dict(dict_to_fill, dictObj, parent_namespace=''):
 
 # -----------------------------------------------------------------------------
 
-def flatten_hierarchical_map(hirearchical_map):
+def flatten_hierarchical_map(hierarchical_map):
     """Helper function that take a hierarchical map and return a flat
     version of it.
     """
     flat_map = {}
-    extract_keys_from_dict(flat_map, hirearchical_map, parent_namespace='')
+    extract_keys_from_dict(flat_map, hierarchical_map, parent_namespace='')
     return flat_map
 
 # -----------------------------------------------------------------------------
@@ -285,7 +285,7 @@ class PFDBObj:
             return getattr(self, key_str)
 
         prefix = ''
-        if self._details_ and '_prefix_' in self._details_:
+        if hasattr(self, '_details_') and '_prefix_' in self._details_:
             prefix = self._details_['_prefix_']
 
         key_str = f'{prefix}{key_str}'
@@ -379,7 +379,7 @@ class PFDBObj:
 
     # ---------------------------------------------------------------------------
 
-    def validate(self, indent=1, workdir=None):
+    def validate(self, indent=1, skip_valid=False, enable_print=True):
         """
         Method to validate sub hierarchy
         """
@@ -396,20 +396,27 @@ class PFDBObj:
                         value = obj._value_
                         add_errors, validation_string = validate_helper(
                             obj, '_value_', value, indent)
-                        print(f'{indent_str}{name}: {validation_string}')
-                        error_count += add_errors
-                    else:
-                        print(f'{indent_str}{name}:')
 
-                    error_count += obj.validate(indent + 1)
+                        if enable_print and (add_errors or not skip_valid):
+                            print(f'{indent_str}{name}: {validation_string}')
+
+                        error_count += add_errors
+                    elif enable_print:
+                        if not skip_valid or obj.validate(enable_print=False):
+                            print(f'{indent_str}{name}:')
+
+                    error_count += obj.validate(indent + 1,
+                                                skip_valid=skip_valid, enable_print=enable_print)
 
             elif hasattr(self, '_details_') and name in self._details_:
                 add_errors, validation_string = validate_helper(
                     self, name, obj, indent)
-                print(f'{indent_str}{name}: {validation_string}')
+                if enable_print and (not skip_valid or add_errors):
+                    print(f'{indent_str}{name}: {validation_string}')
                 error_count += add_errors
             elif obj is not None:
-                print(f'{indent_str}{name}: {obj}')
+                if enable_print and not skip_valid:
+                    print(f'{indent_str}{name}: {obj}')
 
         return error_count
 
@@ -595,6 +602,42 @@ class PFDBObj:
 
     # ---------------------------------------------------------------------------
 
+    def get(self, key='', skip_default=False):
+        value = None
+        tokens = key.split('.')
+        details = None
+        if len(tokens) > 1:
+            container = self.get_selection_from_location(
+                '/'.join(tokens[:-1]))[0]
+            if container is not None:
+                value = container[tokens[-1]] if tokens[-1] in container.__dict__ else None
+            if value is not None and not isinstance(value, PFDBObj):
+                details = container._details_[tokens[-1]]
+        elif len(tokens) == 1:
+            if len(tokens[0]) > 0:
+                value = self[tokens[0]] if tokens[0] in self.__dict__ else None
+                details = self._details_[tokens[0]] if tokens[0] in self._details_ else None
+            else:
+                value = self
+
+        if value is None:
+            return None
+
+        if isinstance(value, PFDBObj):
+            if skip_default:
+                details = value._details_['_value_']
+                if 'history' not in details or len(details['history']) == 0:
+                    return None
+            return value._value_
+
+        if skip_default and details:
+            if 'history' not in details or len(details['history']) == 0:
+                return None
+
+        return value
+
+    # ---------------------------------------------------------------------------
+
     def process_dynamic(self):
         """
         Processing the dynamically defined (user-defined) key names
